pub(crate) async fn new_operations(
grpc: &MassaPublicGrpc,
request: Request<Streaming<NewOperationsRequest>>,
) -> Result<NewOperationsStreamType, GrpcError>Expand description
Creates a new stream of new produced and received operations
pub(crate) async fn new_operations(
grpc: &MassaPublicGrpc,
request: Request<Streaming<NewOperationsRequest>>,
) -> Result<NewOperationsStreamType, GrpcError>Creates a new stream of new produced and received operations